@@ -1,27 +1,12 @@
 import simpleaudio as sa
 import threading
-import os
 import sys
-import wave
-
-
-class WavFile:
-    """
-    Class, which open file with parameters of sound
-    """
-    def __init__(self, path):
-        with wave.open(path, "rb") as f:
-            self.width = f.getsampwidth()
-            self.channels = f.getnchannels()
-            self.rate = f.getframerate()
-            self.frames = f.getnframes()
-            self.data = f.readframes(self.frames)
-            self.duration = float(self.frames) / self.rate
+import os
 
 
 class WavPlayer:
     """
-    Class contains sounds and play sounds
+    Class load sounds from files and play sounds
     """
     def __init__(self):
 
@@ -38,7 +23,7 @@ class WavPlayer:
         else:
             self.play = self.__play_sa
 
-    def add_sound(self, file, name):
+    def add_sound(self, file: str, name: str):
         """
         Function add sound to class from file
         :param file: filename with sound
@@ -57,9 +42,9 @@ class WavPlayer:
         for th in self._threads:
             th.join()
 
-    def __play_sa(self, sound_name):
+    def __play_sa(self, sound_name: str):
         """
-        Function play sound in thread
+        Function play sound in another OS
         :param sound_name: name of sound in class
         :return:
         """
@@ -69,15 +54,15 @@ class WavPlayer:
         self._threads.append(thread)
         thread.start()
 
-    def __play_win(self, sound_name):
+    def __play_win(self, sound_name: str):
         """
-        Fuction play sound on windows
+        Function play sound on windows
         :param sound_name: name of sound in class
         :return:
         """
         self.winsound.PlaySound(self._sounds_files[sound_name], self.winsound.SND_NOSTOP)
 
-    def __play_linux(self, sound_name):
+    def __play_linux(self, sound_name: str):
         """
         Function play sound on linux
         :param sound_name: name of sound in class
